django-require-i18n
===================

Django management command for extracting and compiling
internationalization/localization string resources used in the
`Require.js`_ `i18n plugin`_.


Installation
------------

Use pip_ to install the download and install the package from PyPi_::

  pip install django-require-i18n

Or checkout the source code::

  git clone https://github.com/collab-project/django-require-i18n.git


Documentation
-------------

Check the `doc` directory for more information.


.. _Require.js: http://requirejs.org
.. _pip: https://pypi.python.org/pypi/pip
.. _PyPi: https://pypi.python.org/pypi/djang-require-i18n
.. _i18n plugin: https://github.com/requirejs/i18n